summaryrefslogtreecommitdiffstats
path: root/kaddressbook/views/contactlistview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /kaddressbook/views/contactlistview.h
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kaddressbook/views/contactlistview.h')
-rw-r--r--kaddressbook/views/contactlistview.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kaddressbook/views/contactlistview.h b/kaddressbook/views/contactlistview.h
index c018e4c2..ff09dbe3 100644
--- a/kaddressbook/views/contactlistview.h
+++ b/kaddressbook/views/contactlistview.h
@@ -24,10 +24,10 @@
#ifndef CONTACTLISTVIEW_H
#define CONTACTLISTVIEW_H
-#include <qcolor.h>
-#include <qpixmap.h>
-#include <qtooltip.h>
-#include <qstring.h>
+#include <tqcolor.h>
+#include <tqpixmap.h>
+#include <tqtooltip.h>
+#include <tqstring.h>
#include <klistview.h>
@@ -47,7 +47,7 @@ class DynamicTip : public QToolTip
DynamicTip( ContactListView * parent );
protected:
- void maybeTip( const QPoint & );
+ void maybeTip( const TQPoint & );
private:
};
@@ -61,12 +61,12 @@ public:
const KABC::Addressee &addressee() const { return mAddressee; }
virtual void refresh();
virtual ContactListView* parent();
- virtual QString key ( int, bool ) const;
+ virtual TQString key ( int, bool ) const;
void setHasIM( bool hasIM );
/** Adds the border around the cell if the user wants it.
* This is how the single line config option is implemented.
*/
- virtual void paintCell(QPainter * p, const QColorGroup & cg,
+ virtual void paintCell(TQPainter * p, const TQColorGroup & cg,
int column, int width, int align );
private:
@@ -89,7 +89,7 @@ class ContactListView : public KListView
public:
ContactListView(KAddressBookTableView *view,
KABC::AddressBook *doc,
- QWidget *parent,
+ TQWidget *parent,
const char *name = 0L );
virtual ~ContactListView() {}
//void resort();
@@ -105,13 +105,13 @@ public:
bool singleLine() const { return mSingleLine; }
void setSingleLineEnabled(bool enabled) { mSingleLine = enabled; }
- const QColor &alternateColor() const { return mAlternateColor; }
+ const TQColor &alternateColor() const { return mAlternateColor; }
/** Sets the background pixmap to <i>filename</i>. If the
* QString is empty (QString::isEmpty()), then the background
* pixmap will be disabled.
*/
- void setBackgroundPixmap(const QString &filename);
+ void setBackgroundPixmap(const TQString &filename);
/**
* Sets whether instant messaging presence should be shown in the first column
@@ -140,20 +140,20 @@ protected:
/** Paints the background pixmap in the empty area. This method is needed
* since Qt::FixedPixmap will not scroll with the list view.
*/
- virtual void paintEmptyArea( QPainter * p, const QRect & rect );
- virtual void contentsMousePressEvent(QMouseEvent*);
- void contentsMouseMoveEvent( QMouseEvent *e );
- void contentsDropEvent( QDropEvent *e );
- virtual bool acceptDrag(QDropEvent *e) const;
+ virtual void paintEmptyArea( TQPainter * p, const TQRect & rect );
+ virtual void contentsMousePressEvent(TQMouseEvent*);
+ void contentsMouseMoveEvent( TQMouseEvent *e );
+ void contentsDropEvent( TQDropEvent *e );
+ virtual bool acceptDrag(TQDropEvent *e) const;
protected slots:
- void itemDropped(QDropEvent *e);
+ void itemDropped(TQDropEvent *e);
public slots:
signals:
void startAddresseeDrag();
- void addresseeDropped(QDropEvent *);
+ void addresseeDropped(TQDropEvent *);
private:
KAddressBookTableView *pabWidget;
@@ -166,9 +166,9 @@ private:
bool mToolTips;
bool mShowIM;
- QColor mAlternateColor;
+ TQColor mAlternateColor;
- QPoint presspos;
+ TQPoint presspos;
int mInstantMsgColumn;
};
@@ -105,13 +105,13 @@ public:
/** Sets the background pixmap to <i>filename</i>. If the
- * QString is empty (QString::isEmpty()), then the background
+ * TQString is empty (TQString::isEmpty()), then the background
* pixmap will be disabled.
*/